<?php
class RestClientWarning extends Exception {}
class RestClientError extends ErrorException {}

/**
 * REST-клиент
 * @version 1.0
 * @author Александр Макаров
 * @link http://rmcreative.ru/
 */
class RestClient {
	/**
	 * Послать REST-запрос.
	 *
	 * @param string $url URL.
	 * @param array $args Параметры запроса.
	 * @param array $options Опции CURL.
	 *
	 * @return string Ответ.
	 */
	protected function request($url, array $args, array $options = array()) {
		if(empty($url)) throw new RestClientError('Не задан URL.');
		$curl = curl_init();
		
		curl_setopt($curl, CURLOPT_URL, $this->buildUrl($url, $args));
		curl_setopt($curl, CURLOPT_FAILONERROR, 1);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);

		// Настраиваемые параметры
		$useragent = 'PHP RestClient 1.0';
		if(!empty($options['useragent'])) $useragent = $options['useragent'];
		curl_setopt($curl, CURLOPT_USERAGENT, $useragent);

		// Таймаут в сек.
		$timeout = 30;
		if(!empty($options['timeout'])) $timeout = $options['timeout'];
		curl_setopt($curl, CURLOPT_TIMEOUT, $timeout);

		$result = curl_exec($curl);

		$errnum = curl_errno($curl);
		if($errnum) {
			throw new RestClientError(curl_error($curl), $errnum);
		}

		curl_close($curl);

		return $result;
	}

	/**
	 * Послать запрос к URL, возвращающему JSON.
	 *
	 * @param string $url
	 * @param array $args
	 * @param array $options
	 * @return array
	 */
	function requestJson($url, array $args, array $options = array()){
		return json_decode($this->request($url, $args, $options));
	}

	/**
	 * Послать запрос к URL, возвращающему XML.
	 *
	 * @param string $url
	 * @param array $args
	 * @param array $options
	 * @return array
	 */
	function requestXml($url, array $args, array $options = array()){
		return simplexml_load_string($this->request($url, $args, $options));
	}

	/**
	 * Добавляет параметры к URL.
	 *
	 * @param string $url Базовый URL.
	 * @param array $args Масссив параметров.
	 * @return string Полный URL.
	 */
	private function buildUrl($url, $args) {
		foreach ($args as $key => $value) {
			$query_string .= $key.'='.urlencode($value).'&';
		}

		return $url.'?'.$query_string;
	}
}