<?php
/**
 * API Яндекс.Спеллера
 * @version 1.0
 * @author Александр Макаров
 * @link http://rmcreative.ru/
 *
 * @see http://api.yandex.ru/speller/
 */
class YandexSpeller extends RestClient {
	private $useragent = 'PHP Yandex.Speller Client';

	protected $jsonUrl = 'http://speller.yandex.net/services/spellservice.json/';
	protected $encoding = 'utf-8';

	/**
	 * Пропускать слова, написанные заглавными буквами, например, "ВПК".
	 */
	const OPT_IGNORE_UPPERCASE = 1;

	/**
	 * Пропускать слова с цифрами, например, "авп17х4534".
	 */
	const OPT_IGNORE_DIGITS = 2;

	/**
	 * Пропускать интернет-адреса, почтовые адреса и имена файлов.
	 */
	const OPT_IGNORE_URLS = 4;

	/**
	 * Подсвечивать повторы слов, идущие подряд. Например, "я полетел на на Кипр".
	 */
	const OPT_FIND_REPEAT_WORDS = 8;

	/**
	 * Пропускать слова, написанные латиницей, например, "madrid".
	 */
	const OPT_IGNORE_LATIN = 10;

	/**
	 * Только проверять текст, не выдавая вариантов для замены.
	 */
	const OPT_NO_SUGGEST = 20;

	/**
	 * Отмечать слова, написанные латиницей, как ошибочные.
	 */
	const OPT_FLAG_LATIN = 80;

	/**
	 * Кодировка входного запроса UTF-8
	 */
	const ENCODING_UTF8 = 'utf-8';

	/**
	 * Кодировка входного запроса 1251
	 */
	const ENCODING_1251 = '1251';
	
	/**
	 * Слова нет в словаре.
	 */
	const ERROR_UNKNOWN_WORD = 1;

	/**
	 * Повтор слова.
	 */
	const ERROR_REPEAT_WORD = 2;

	/**
	 * Неверное употребление прописных и строчных букв.
	 */
	const ERROR_CAPITALIZATION = 3;

	/**
	 * Текст содержит слишком много ошибок.
	 * При этом приложение может отправить Яндекс.Спеллеру оставшийся
	 * непроверенным текст в следующем запросе.
	 */
	const ERROR_TOO_MANY_ERRORS = 4;

	/**
	 * Проверяет орфографию в указанном отрывке текста.
	 *
	 * @param string $text Текст для проверки. Максимальный размер текста – 10 Кбайт.
	 * @param string $lang Языки проверки (перечисляются через запятую). ru – русский; uk – украинский; en – английский. По умолчанию "ru, en".
	 * @param int $options Опции Яндекс.Спеллера. Значением параметра является сумма значений требуемых опций.
	 * @param string Кодировка.
	 *
	 * @return string
	 *
	 * @see http://api.yandex.ru/speller/doc/dg/reference/checkText.xml
	 */
	function checkText($text, $lang = null, $options = null, $encoding = null){
		if(empty($text)) return array();
		$param = array();
		$param['text'] = $text;
		if($lang!==null) $param['lang'] = $lang;
		if($options!==null) $param['options'] = $options;
		if($encoding!==null) $param['ie'] = $encoding;
		return $this->requestJson($this->jsonUrl.'checkText', $param, array(
			'useragent' => $this->useragent
		));
	}

	/**
	 * Проверяет орфографию в указанных фрагментах текста. Для каждого фрагмента возвращается отдельный массив ошибок с подсказками.
	 *
	 * @param array[string] $text Массив текстов для проверки. Максимальный размер – 10 Кбайт.
	 * @param string $lang Языки проверки (перечисляются через запятую). ru – русский; uk – украинский; en – английский. По умолчанию "ru, en".
	 * @param int $options Опции Яндекс.Спеллера. Значением параметра является сумма значений требуемых опций.
	 * @param string Кодировка.
	 *
	 * @return array
	 *
	 * @see http://api.yandex.ru/speller/doc/dg/reference/checkTexts.xml
	 */
	function checkTexts(array $text, $lang = null, $options = null, $encoding = null){
		$param = array();
		$param['text'] = $text;
		if($lang!==null) $param['lang'] = $lang;
		if($options!==null) $param['options'] = $options;
		if($encoding!==null) $param['ie'] = $encoding;
		return $this->requestJson($this->jsonUrl.'checkTexts', $param, array(
			'useragent' => $this->useragent
		));
	}
}